pub struct Builder {
pub url: String,
pub headers: Headers,
}Fields
url: Stringheaders: HeadersImplementations
Sourceimpl Builder
impl Builder
pub fn new(url: impl Into<String>) -> Builder
Sourcepub fn insert_header(
&mut self,
header_name: impl ToString,
header_value: impl ToString,
) -> &mut Self
pub fn insert_header( &mut self, header_name: impl ToString, header_value: impl ToString, ) -> &mut Self
Add arbitrary headers to the request. For instance when you may want to connect through an API gateway that needs an API key header.
Sourcepub fn sign_up(
&self,
email_or_phone: EmailOrPhone,
password: impl AsRef<str>,
) -> Request
pub fn sign_up( &self, email_or_phone: EmailOrPhone, password: impl AsRef<str>, ) -> Request
Signs up for a new account
Sourcepub fn sign_in(
&self,
email_or_phone: EmailOrPhone,
password: impl AsRef<str>,
) -> Request
pub fn sign_in( &self, email_or_phone: EmailOrPhone, password: impl AsRef<str>, ) -> Request
Signs into an existing account
Sourcepub fn send_otp(
&self,
email_or_phone: EmailOrPhone,
should_create_user: bool,
) -> Request
pub fn send_otp( &self, email_or_phone: EmailOrPhone, should_create_user: bool, ) -> Request
Sends an OTP Code and creates user if it does not exist
pub fn verify_otp<T: Serialize>(&self, params: T) -> Request
Sourcepub fn reset_password_for_email(&self, email: impl AsRef<str>) -> Request
pub fn reset_password_for_email(&self, email: impl AsRef<str>) -> Request
Sends password recovery email
Sourcepub fn refresh_access_token(&self, refresh_token: impl AsRef<str>) -> Request
pub fn refresh_access_token(&self, refresh_token: impl AsRef<str>) -> Request
Refreshes the current session by refresh token
Sourcepub fn update_user(&self, user: UserAttributes, jwt: impl AsRef<str>) -> Request
pub fn update_user(&self, user: UserAttributes, jwt: impl AsRef<str>) -> Request
Updates a user
Sourcepub fn invite_user_by_email(&self, email: impl AsRef<str>) -> Request
pub fn invite_user_by_email(&self, email: impl AsRef<str>) -> Request
Invites a user via email
Sourcepub fn list_users(&self, query_string: Option<String>) -> Request
pub fn list_users(&self, query_string: Option<String>) -> Request
Lists all users based on a query string
Sourcepub fn get_user_by_id(&self, user_id: impl AsRef<str>) -> Request
pub fn get_user_by_id(&self, user_id: impl AsRef<str>) -> Request
Gets a user by id
Sourcepub fn create_user<T: Serialize>(&self, user: T) -> Request
pub fn create_user<T: Serialize>(&self, user: T) -> Request
Creates a user
Sourcepub fn update_user_by_id<T: Serialize>(
&self,
id: impl AsRef<str>,
user: T,
) -> Request
pub fn update_user_by_id<T: Serialize>( &self, id: impl AsRef<str>, user: T, ) -> Request
Updates a user by id
Sourcepub fn delete_user(&self, user_id: impl AsRef<str>) -> Request
pub fn delete_user(&self, user_id: impl AsRef<str>) -> Request
Deletes a user by id